exceptiontools.TimeSignatureError
=================================

.. abjad-lineage:: abjad.tools.exceptiontools.TimeSignatureError.TimeSignatureError

.. autoclass:: abjad.tools.exceptiontools.TimeSignatureError.TimeSignatureError
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.TimeSignatureError.TimeSignatureError.__delattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TimeSignatureError.TimeSignatureError.__getitem__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TimeSignatureError.TimeSignatureError.__getslice__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TimeSignatureError.TimeSignatureError.__repr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TimeSignatureError.TimeSignatureError.__setattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TimeSignatureError.TimeSignatureError.__setstate__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TimeSignatureError.TimeSignatureError.__str__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TimeSignatureError.TimeSignatureError.__unicode__
   :noindex:
